summaryrefslogtreecommitdiffstats
path: root/base/android/library_loader
diff options
context:
space:
mode:
authorpetrcermak <petrcermak@chromium.org>2015-05-22 04:51:32 -0700
committerCommit bot <commit-bot@chromium.org>2015-05-22 11:52:13 +0000
commitdbab8d0ee3ec47aa7776df626d1346de68b59bf3 (patch)
tree1cd535b0fdd002a032e5e31d745471512ae1e5bb /base/android/library_loader
parentb46c430ac8abeb3a017bfba9b4eab915fa539cea (diff)
downloadchromium_src-dbab8d0ee3ec47aa7776df626d1346de68b59bf3.zip
chromium_src-dbab8d0ee3ec47aa7776df626d1346de68b59bf3.tar.gz
chromium_src-dbab8d0ee3ec47aa7776df626d1346de68b59bf3.tar.bz2
Remove no map executable support probe and fallback
This patch removes the check for support for memory mapping files inside the Chrome APK with executable permissions and the associated fallback. Background: We were checking the APK executable mmap support to determine when we could start loading directly from APK on 32-bit devices. However, we decided to do this only on L+ devices (where the support is mandatory). BUG=489267 Review URL: https://codereview.chromium.org/1152493002 Cr-Commit-Position: refs/heads/master@{#331094}
Diffstat (limited to 'base/android/library_loader')
-rw-r--r--base/android/library_loader/library_load_from_apk_status_codes.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/base/android/library_loader/library_load_from_apk_status_codes.h b/base/android/library_loader/library_load_from_apk_status_codes.h
index 9591d3f..8910d48 100644
--- a/base/android/library_loader/library_load_from_apk_status_codes.h
+++ b/base/android/library_loader/library_load_from_apk_status_codes.h
@@ -17,11 +17,13 @@ enum LibraryLoadFromApkStatusCodes {
// The loader was unable to determine whether the functionality is supported.
LIBRARY_LOAD_FROM_APK_STATUS_CODES_UNKNOWN = 0,
- // The device does not support loading a library directly from the APK file.
- LIBRARY_LOAD_FROM_APK_STATUS_CODES_NOT_SUPPORTED = 1,
+ // The device does not support loading a library directly from the APK file
+ // (obsolete).
+ LIBRARY_LOAD_FROM_APK_STATUS_CODES_NOT_SUPPORTED_OBSOLETE = 1,
// The device supports loading a library directly from the APK file.
- LIBRARY_LOAD_FROM_APK_STATUS_CODES_SUPPORTED = 2,
+ // (obsolete).
+ LIBRARY_LOAD_FROM_APK_STATUS_CODES_SUPPORTED_OBSOLETE = 2,
// The Chromium library was successfully loaded directly from the APK file.
LIBRARY_LOAD_FROM_APK_STATUS_CODES_SUCCESSFUL = 3,
@@ -31,8 +33,9 @@ enum LibraryLoadFromApkStatusCodes {
LIBRARY_LOAD_FROM_APK_STATUS_CODES_USED_UNPACK_LIBRARY_FALLBACK = 4,
// The Chromium library was successfully loaded using the no map executable
- // support fallback.
- LIBRARY_LOAD_FROM_APK_STATUS_CODES_USED_NO_MAP_EXEC_SUPPORT_FALLBACK = 5,
+ // support fallback (obsolete).
+ LIBRARY_LOAD_FROM_APK_STATUS_CODES_USED_NO_MAP_EXEC_SUPPORT_FALLBACK_OBSOLETE
+ = 5,
// End sentinel.
LIBRARY_LOAD_FROM_APK_STATUS_CODES_MAX = 6,